% =========================================================================
% Code for "Pandemic Recessions and Contact Tracing"
% by Leonardo Melosi and Matthias Rottner
% Journal of the European Economic Association, forthcoming
% This code generates Figure 2 (it is called within the file main_run.m)
% =========================================================================

addpath Simulations
get_setup;


% define figure properties
T_plot = 150;

% Load paths for the different tracing technology
load pf_011; load pf_111; load pf_211; load pf_1111

% Required Tested
pf_011.E_tot(1:T_plot,1) = zeros(length(pf_111.E_tt(1:T_plot,1)),1);
pf_111.E_tot(1:T_plot,1) = pf_111.E_tt(1:T_plot,1).*pf_111.pi_bar_tt(1:T_plot,1);
pf_211.E_tot(1:T_plot,1) = pf_211.E_tt(1:T_plot,1).*pf_211.pi_bar_tt(1:T_plot,1) + pf_211.E_ttl(1:T_plot,1).*pf_211.pi_bar_ttl(1:T_plot,1);
pf_1111.E_tot(1:T_plot,1) = pf_1111.E_tt(1:T_plot,1).*pf_1111.pi_bar_tt(1:T_plot,1);
% Probability to be tested on aggregate
pf_011.pic_G = (((1-P.pii-P.pir)*(pf_011.pic_A(1:T_plot,1)).*pf_011.A(1:T_plot,1) + (pf_011.pic_T(1:T_plot,1)).*pf_011.T(1:T_plot,1) ) ./((1-P.pii-P.pir).*pf_011.A(1:T_plot,1)+pf_011.T(1:T_plot,1)));
pf_111.pic_G = (((1-P.pii-P.pir)*(pf_111.pic_A(1:T_plot,1)).*pf_111.A(1:T_plot,1) + (pf_111.pic_T(1:T_plot,1)).*pf_111.T(1:T_plot,1) ) ./((1-P.pii-P.pir).*pf_111.A(1:T_plot,1)+pf_111.T(1:T_plot,1)));
pf_211.pic_G = (((1-P.pii-P.pir)*(pf_211.pic_A(1:T_plot,1)).*pf_211.A(1:T_plot,1) + (pf_211.pic_T(1:T_plot,1)).*pf_211.T(1:T_plot,1) ) ./((1-P.pii-P.pir).*pf_211.A(1:T_plot,1)+pf_211.T(1:T_plot,1)));
pf_1111.pic_G = (((1-P.pii-P.pir)*(pf_1111.pic_A(1:T_plot,1)).*pf_1111.A(1:T_plot,1) + (pf_1111.pic_T(1:T_plot,1)).*pf_1111.T(1:T_plot,1) ) ./((1-P.pii-P.pir).*pf_1111.A(1:T_plot,1)+pf_1111.T(1:T_plot,1)));
% Positive Test Ratio
pf_011.Epos(1:T_plot,1) = zeros(length(pf_111.E_tt(1:T_plot,1)),1);
pf_111.Epos(1:T_plot,1) = ((1-P.pii-P.pir)*(pf_111.pic_A(1:T_plot,1)).*pf_111.A(1:T_plot,1) + (pf_111.pic_T(1:T_plot,1)).*pf_111.T(1:T_plot,1) ) ./ pf_111.E_tot(1:T_plot,1);
pf_211.Epos(1:T_plot,1) = ((1-P.pii-P.pir)*(pf_211.pic_A(1:T_plot,1)).*pf_211.A(1:T_plot,1) + (pf_211.pic_T(1:T_plot,1)).*pf_211.T(1:T_plot,1) ) ./ pf_211.E_tot(1:T_plot,1);
pf_1111.Epos(1:T_plot,1) = ((1-P.pii-P.pir)*(pf_1111.pic_A(1:T_plot,1)).*pf_1111.A(1:T_plot,1) + (pf_1111.pic_T(1:T_plot,1)).*pf_1111.T(1:T_plot,1) ) ./ pf_1111.E_tot(1:T_plot,1);

% Reproduction Number
len = 50; % Define how far in the future
for t = 1:T-len-20  % Choose horizon
    term_sum = [];
    for j = 0:len
    tau_j = (pf_011.T(t+j,1)./pf_011.A(t+j,1));  %tau_j
        for kk = 0:j
            if j == 0
                term_prod = 1; % Product term if j = 0
            else
                term_prod = prod(1-pf_011.pic_A(t+1:t+j));  % Product term j>0
            end
        end
    term_temp = tau_j*(1-P.pir-P.pii)^j*term_prod; % Equation with pi_T
    term_sum = [term_sum; term_temp];
    end

    if t ==1
        pf_011.R_0(t) = 1*sum(term_sum);  % Total equation
    else
        pf_011.R_0(t) = (1-pf_011.pic_T(t-1))*sum(term_sum); % Total equation
    end
end

for t = 1:T-len-20  % Choose horizon
    term_sum = [];
    for j = 0:len
    tau_j = (pf_111.T(t+j,1)./pf_111.A(t+j,1));  %tau_j
        for kk = 0:j
            if j == 0
                term_prod = 1; % Product term if j = 0
            else
                term_prod = prod(1-pf_111.pic_A(t+1:t+j));  % Product term j>0
            end
        end
    term_temp = tau_j*(1-P.pir-P.pii)^j*term_prod; % Equation with pi_T
    term_sum = [term_sum; term_temp];
    end

    if t ==1
        pf_111.R_0(t) = 1*sum(term_sum);  % Total equation
    else
        pf_111.R_0(t) = (1-pf_111.pic_T(t-1))*sum(term_sum); % Total equation
    end
end

for t = 1:T-len-20  % Choose horizon
    term_sum = [];
    for j = 0:len
    tau_j = (pf_211.T(t+j,1)./pf_211.A(t+j,1));  %tau_j
        for kk = 0:j
            if j == 0
                term_prod = 1; % Product term if j = 0
            else
                term_prod = prod(1-pf_211.pic_A(t+1:t+j));  % Product term j>0
            end
        end
    term_temp = tau_j*(1-P.pir-P.pii)^j*term_prod; % Equation with pi_T
    term_sum = [term_sum; term_temp];
    end

    if t ==1
        pf_211.R_0(t) = 1*sum(term_sum);  % Total equation
    else
        pf_211.R_0(t) = (1-pf_211.pic_T(t-1))*sum(term_sum); % Total equation
    end
end

for t = 1:T-len-20  % Choose horizon 
    term_sum = [];
    for j = 0:len
    tau_j = (pf_1111.T(t+j,1)./pf_1111.A(t+j,1));  %tau_j
        for kk = 0:j
            if j == 0
                term_prod = 1; % Product term if j = 0
            else
                term_prod = prod(1-pf_1111.pic_A(t+1:t+j));  % Product term j>0
            end
        end
    term_temp = tau_j*(1-P.pir-P.pii)^j*term_prod; % Equation with pi_T
    term_sum = [term_sum; term_temp];
    end

    if t ==1
        pf_1111.R_0(t) = 1*sum(term_sum);  % Total equation
    else
        pf_1111.R_0(t) = (1-pf_1111.pic_T(t-1))*sum(term_sum); % Total equation
    end
end
%% Generate Figure 2

opts.Colors     = get(groot,'defaultAxesColorOrder');
opts.saveFolder = 'Figures/';
opts.width      = 17;
opts.height     = 20;
opts.fontType   = 'Times New Roman';
opts.fontSize   = 9;
set(0,'DefaultFigureRenderer','painters')
set(0,'DefaultLineLineWidth',1.5)
set(0,'DefaultLineMarkerSize',4)
fig = figure; clf;

subplot(4,2,1);hold on;grid on;box on;
plot(100*pf_011.A(1:T_plot),'-.','Color',[64 170 64]./255,'LineWidth',1.5);
plot(100*pf_111.A(1:T_plot),'b','LineWidth',1.5);
plot(100*pf_211.A(1:T_plot),'r--','LineWidth',1.5);
plot(100*pf_1111.A(1:T_plot),'k:','LineWidth',1.5)
plot([1:5:T_plot T_plot],100*pf_1111.A([1:5:T_plot T_plot]),'kx','LineWidth',1.5,'MarkerSize',2)
title('Infected (Asymptomatic)');ylabel('% of population');xlabel('Weeks')

subplot(4,2,2);hold on;grid on;box on;

plot(100*pf_011.R(1:T_plot),'-.','Color',[64 170 64]./255,'LineWidth',1.5)
plot(100*pf_111.R(1:T_plot),'b','LineWidth',1.5);
plot(100*pf_211.R(1:T_plot),'r--','LineWidth',1.5);
plot(100*pf_1111.R(1:T_plot),'k:','LineWidth',1.5);
plot([1:5:T_plot T_plot],100*pf_1111.R([1:5:T_plot T_plot]),'kx','LineWidth',1.5,'MarkerSize',2)
title('Recovered');xlabel('Weeks');ylabel('% of population')

subplot(4,2,3);hold on;grid on;box on;
plot(100*pf_011.D(1:T_plot),'-.','Color',[64 170 64]./255,'LineWidth',1.5)
plot(100*pf_111.D(1:T_plot),'b','LineWidth',1.5);
plot(100*pf_211.D(1:T_plot),'r--','LineWidth',1.5);
plot(100*pf_1111.D(1:T_plot),'k:','LineWidth',1.5)
plot([1:5:T_plot T_plot],100*pf_1111.D([1:5:T_plot T_plot]),'kx','LineWidth',1.5,'MarkerSize',2)
title('Deaths');xlabel('Weeks');ylabel('% of population')

subplot(4,2,4);hold on;grid on;box on;
plot(100*(pf_011.Cons(1:T_plot)-P.C)/P.C,'-.','Color',[64 170 64]./255,'LineWidth',1.5)
plot(100*(pf_111.Cons(1:T_plot)-P.C)/P.C,'b','LineWidth',1.5);
plot(100*(pf_211.Cons(1:T_plot)-P.C)/P.C,'r--','LineWidth',1.5);
plot(100*(pf_1111.Cons(1:T_plot)-P.C)/P.C,'k:','LineWidth',1.5)
plot([1:5:T_plot T_plot],100*(pf_1111.Cons([1:5:T_plot T_plot])-P.C)/P.C,'kx','LineWidth',1.5,'MarkerSize',2)
title('Aggregate Consumption');ylabel('% dev. from initial ss');xlabel('Weeks')

subplot(4,2,5);hold on;grid on;box on;
plot(100*pf_011.E_tot(1:T_plot),'-.','Color',[64 170 64]./255,'LineWidth',1.5);
plot(100*pf_111.E_tot(1:T_plot),'b','LineWidth',1.5);
plot(100*pf_211.E_tot(1:T_plot),'r--','LineWidth',1.5);
plot(100*pf_1111.E_tot(1:T_plot),'k:','LineWidth',1.5);
plot([1:5:T_plot T_plot],100*pf_1111.E_tot([1:5:T_plot T_plot]),'kx','LineWidth',1.5,'MarkerSize',2)
ylim([0 12.5])
title('Total Tests');xlabel('Weeks');ylabel('% of population')

subplot(4,2,6);hold on;grid on;box on;
plot(pf_011.R_0(1:T_plot),'-.','Color',[64 170 64]./255,'LineWidth',1.5);
plot(pf_111.R_0(1:T_plot),'b','LineWidth',1.5);
plot(pf_211.R_0(1:T_plot),'r--','LineWidth',1.5);
plot(pf_1111.R_0(1:T_plot),'k:','LineWidth',1.5);
plot([1:5:T_plot T_plot],pf_1111.R_0([1:5:T_plot T_plot]),'kx','LineWidth',1.5,'MarkerSize',2)
title('Effective Reproduction Number R_t^E');ylabel('Level');xlabel('Weeks')

subplot(4,2,7);hold on;grid on;box on;
plot(100*pf_011.pic_T(1:T_plot),'-.','Color',[64 170 64]./255,'LineWidth',1.5);
plot(100*pf_111.pic_T(1:T_plot),'b','LineWidth',1.5);
plot(100*pf_211.pic_T(1:T_plot),'r--','LineWidth',1.5);
plot(100*pf_1111.pic_T(1:T_plot),'k:','LineWidth',1.5);
plot([1:5:T_plot T_plot],100*pf_1111.pic_T([1:5:T_plot T_plot]),'kx','LineWidth',1.5,'MarkerSize',2)
ylim([0 45])
title('Test Probability Newly Infected \pi_t^T');ylabel('%');xlabel('Weeks')

subplot(4,2,8);hold on;grid on;box on;
l81 =plot(100*pf_011.pic_A(1:T_plot),'-.','Color',[64 170 64]./255,'LineWidth',1.5);
l82 = plot(100*pf_111.pic_A(1:T_plot),'b','LineWidth',1.5);
l83 = plot(100*pf_211.pic_A(1:T_plot),'r--','LineWidth',1.5);
l84 = plot([1:5:T_plot T_plot],100*pf_1111.pic_A([1:5:T_plot T_plot]),'kx:','LineWidth',1.5,'MarkerSize',2);
ylabel('%');xlabel('Weeks');title('Test Probability Asymptomatic \pi_t^A')

l1 = legend([l82 l83 l81 l84],'Contact Tracing','Comprehensive Tracing','No Testing','Random Testing','Location','South','Orientation','horizontal');
l1.Position(2) = 0.025;l1.Position(1) = 0.07;

% Scaling
fig.Units               = 'centimeters';
fig.Position(3)         = opts.width;
fig.Position(4)         = opts.height;
set(fig.Children,'FontName','Times','FontSize', 9);

% Print
print([opts.saveFolder 'Figure2_MR_JEEA'], '-dpng', '-r600')
print([opts.saveFolder 'Figure2_MR_JEEA'], '-depsc2', '-r600')
