% =========================================================================
% Code for "Pandemic Recessions and Contact Tracing"
% by Leonardo Melosi and Matthias Rottner
% Journal of the European Economic Association, forthcoming
% This code generates Figure G.2 in the Online Appendix
% (it is called within the file main_run.m)
% =========================================================================

get_setup

% Note that the calculation can take quite some time, especially without
% several cores. Therefore, we have chosen as default that this optimization
% is skipped and the calculations are read in directly

opt_calG4 = 0; % Set to 1 if calculation should be done instead of loading results

if opt_calG4 == 1
    disp('To be calculated ...')
    

    % Loop over different P.pii
    mu_cQ_l = 21;

    P.trace =1;
    P.Choice_Ups = 1;
    mu_cQ_vector = linspace(0.0,2.,mu_cQ_l);
    mu_cQ_mat_1 = zeros(4,mu_cQ_l);
    for mu_cQ_i = 1:length(mu_cQ_vector)
        disp(['Scenario 1: ' num2str(mu_cQ_i) '/' num2str(length(mu_cQ_vector))])
        P.mu_cQ      = mu_cQ_vector(mu_cQ_i); 
        [pf] = eqm_Exposure(P,T); 
        mu_cQ_mat_1(:,mu_cQ_i)= [pf.Util_s(1),mean(pf.Cons),pf.D(end-1), pf.R(end-1)];
    end

    P.trace = 7;
    mu_cQ_mat_2 = zeros(4,mu_cQ_l);
    for mu_cQ_i = 1:length(mu_cQ_vector)
        disp(['Scenario 2: ' num2str(mu_cQ_i) '/' num2str(length(mu_cQ_vector))])
        P.mu_cQ     = mu_cQ_vector(mu_cQ_i); 
        [pf] = eqm_Exposure(P,T);
        mu_cQ_mat_2(:,mu_cQ_i)= [pf.Util_s(1),mean(pf.Cons),pf.D(end-1), pf.R(end-1)];
    end

    P.trace = 2;
    P.Choice_Ups = 1;
    mu_cQ_mat_3 = zeros(4,mu_cQ_l);
    for mu_cQ_i = 1:length(mu_cQ_vector)
        disp(['Scenario 3: ' num2str(mu_cQ_i) '/' num2str(length(mu_cQ_vector))])
        P.mu_cQ     = mu_cQ_vector(mu_cQ_i); 
        [pf] = eqm_Exposure(P,T);
        mu_cQ_mat_3(:,mu_cQ_i)= [pf.Util_s(1),mean(pf.Cons),pf.D(end-1), pf.R(end-1)];
    end

    P.mu_cQ     = 1;

    save simulations/FigureG2_workspace.mat mu_cQ_vector mu_cQ_mat_1 mu_cQ_mat_2 mu_cQ_mat_3

end


%%

load simulations/FigureG2_workspace.mat

opts.Colors     = get(groot,'defaultAxesColorOrder');
opts.saveFolder = 'Figures/';
opts.width      = 17;
opts.height     = 8;
opts.fontType   = 'Times New Roman';
opts.fontSize   = 9;
set(0,'DefaultFigureRenderer','painters')
set(0,'DefaultLineLineWidth',1.5)
set(0,'DefaultLineMarkerSize',4)
fig = figure; clf

subplot(9,3,1:3:22);hold on;grid on;box on;
plot(mu_cQ_vector, 100*(exp((1-P.beta)*(mu_cQ_mat_1(1,:)-P.Util))-1),'b','LineWidth',1.5);
plot(mu_cQ_vector,100*(exp((1-P.beta)*(mu_cQ_mat_2(1,:)-P.Util))-1),'r--','LineWidth',1.5);
plot(mu_cQ_vector,100*(exp((1-P.beta)*(mu_cQ_mat_3(1,:)-P.Util))-1),'k-.','LineWidth',1.5);
axis tight
ylim([-1.5 -0.7])
title('Welfare');ylabel('CE (%)');xlabel('Quarantine Tax \mu_c^Q')

subplot(9,3,2:3:23);hold on;grid on;box on;
plot(mu_cQ_vector,mu_cQ_mat_1(2,:),'b','LineWidth',1.5); 
plot(mu_cQ_vector,mu_cQ_mat_2(2,:),'r--','LineWidth',1.5); 
plot(mu_cQ_vector,mu_cQ_mat_3(2,:),'k-.','LineWidth',1.5);
axis tight
ylim([1075 1105])
ylabel('$');title('Average Consumption');xlabel('Quarantine Tax \mu_c^Q')

subplot(9,3,3:3:24);hold on;grid on;box on;
p41 = plot(mu_cQ_vector,100*mu_cQ_mat_1(3,:),'b','LineWidth',1.5);hold on;
p42 = plot(mu_cQ_vector,100*mu_cQ_mat_2(3,:),'r--','LineWidth',1.5); hold on;
p43 = plot(mu_cQ_vector,100*mu_cQ_mat_3(3,:),'k-.','LineWidth',1.5);
title('Deaths');ylabel('% of population');xlabel('Quarantine Tax \mu_c^Q')
axis tight
ylim([100*0.0011 100*0.0022])

l1 = legend([p41,p43,p42 ],'Contact Tracing','Comprehensive Tracing','All Exposed Quarantined','Orientation','Horizontal'); %,'+ Lockdown'
l1.Position(2) = 0.015;l1.Position(1) = 0.15;

fig.Units               = 'centimeters';
fig.Position(3)         = opts.width;
fig.Position(4)         = opts.height;

print([opts.saveFolder 'FigureG2_MR_JEEA'], '-dpng', '-r600')
print([opts.saveFolder 'FigureG2_MR_JEEA'], '-depsc2', '-r600')
   
   
   
  