% =========================================================================
% Code for "Pandemic Recessions and Contact Tracing"
% by Leonardo Melosi and Matthias Rottner
% Journal of the European Economic Association, forthcoming
% This code generates Figure H.1 in the Online Appendix
% (it is called within the file main_run.m)
% =========================================================================


get_setup;

trace_vec = [1 1 2];
choice_ups_vec = [2 1 2];
P.Ups_flatrate = 1.0;
P.Choice_lock = 2;
P.lock_start= 1;
P.lock_end = 26;52;

lockdown_vec = [0:0.01:0.5];
Util_res = zeros(3,length(lockdown_vec),T);
Pop_res = zeros(3,length(lockdown_vec),T);
Cons_mean = zeros(3,length(lockdown_vec),T);
Labor_mean = zeros(3,length(lockdown_vec),T);
R0_mean = zeros(3,length(lockdown_vec),T);
tau_mean = zeros(3,length(lockdown_vec),T);


% Note that the calculation can take quite some time, especially without
% several cores. Therefore, we have chosen as default that this optimization
% is skipped and the calculations are read in directly

opt_calH5 = 0; % Set to 1 if calculation should be done instead of loading results

if opt_calH5 == 1
    disp('To be calculated ...')
    for mm = 1:3
        P.trace = trace_vec(mm);
        P.Choice_Ups = choice_ups_vec(mm);
        for jj = 1:length(lockdown_vec)
            disp(['Scenario ' num2str(mm) ': '  num2str(jj) '/' num2str(length(lockdown_vec))])
            P.lockdown = lockdown_vec(jj);
            P.up_w = 0.975;
            [pf] = eqm_Exposure(P,T); 
            Util_res(mm,jj,1:T) = (pf.U(1:T));
            Pop_res(mm,jj,1:T)  = pf.Pop(1:T);
            Cons_mean(mm,jj,1:T) = (pf.Cons(1:T));
            Labor_mean(mm,jj,1:T) = (pf.N(1:T));
            R0_mean(mm,jj,1:T) = (pf.R_0(1:T));
            tau_mean(mm,jj,1:T) = (pf.tau(1:T));
        end
    end
    save simulations/FigureH1_workspace.mat Util_res Pop_res Cons_mean Labor_mean R0_mean tau_mean
end 

%%
load simulations/FigureH1_workspace.mat

addpath Simulations

opts.Colors     = get(groot,'defaultAxesColorOrder');
opts.saveFolder = 'Figures/';
opts.width      = 17;
opts.height     = 12;
opts.fontType   = 'Times New Roman';
opts.fontSize   = 9;
set(0,'DefaultFigureRenderer','painters')
set(0,'DefaultLineLineWidth',1.5)
set(0,'DefaultLineMarkerSize',4)

start_lock_fig = 1;
end_lock_fig = length(lockdown_vec);
Util_res2 = 100*(exp((1-P.beta)*(Util_res(:,:,:)-P.Util))-1);

fig = figure; clf

subplot(11,2,[1 3 5 7]);hold on;box on;
plot(lockdown_vec(start_lock_fig:end_lock_fig),Util_res2(1,start_lock_fig:end_lock_fig,1),'b');
plot(lockdown_vec(1,start_lock_fig:end_lock_fig),Util_res2(2,start_lock_fig:end_lock_fig,1),'-.','Color',[64 170 64]./255);
plot(lockdown_vec(start_lock_fig:end_lock_fig),Util_res2(3,start_lock_fig:end_lock_fig,1),'r--');
title('Welfare');ylabel('CE (%)');xlabel('Consumption Tax \mu_{c}^L')
ylim([-2.5 0]);xlim([lockdown_vec(start_lock_fig) lockdown_vec(end_lock_fig)])

subplot(11,2,[2 4 6 8]);hold on;box on;
plot(lockdown_vec(start_lock_fig:end_lock_fig),100*(1-squeeze(Pop_res(1,start_lock_fig:end_lock_fig,end))),'b');
plot(lockdown_vec(start_lock_fig:end_lock_fig),100*(1-squeeze(Pop_res(2,start_lock_fig:end_lock_fig,end))),'-.','Color',[64 170 64]./255);
plot(lockdown_vec(start_lock_fig:end_lock_fig),100*(1-squeeze(Pop_res(3,start_lock_fig:end_lock_fig,end))),'r--');
xlim([lockdown_vec(start_lock_fig) lockdown_vec(end_lock_fig)])
ylabel('%');xlabel('Consumption Tax \mu_{c}^L');title('Total Deaths')

subplot(11,2,[13 15 17 19]);hold on;box on;
plot(lockdown_vec(start_lock_fig:end_lock_fig), mean(squeeze(Cons_mean(1,start_lock_fig:end_lock_fig,:))'),'b');
plot(lockdown_vec(start_lock_fig:end_lock_fig),mean(squeeze(Cons_mean(2,start_lock_fig:end_lock_fig,:))'),'-.','Color',[64 170 64]./255);
plot(lockdown_vec(start_lock_fig:end_lock_fig), mean(squeeze(Cons_mean(3,start_lock_fig:end_lock_fig,:))'),'r--');
xlim([lockdown_vec(start_lock_fig) lockdown_vec(end_lock_fig)])
xlabel('Consumption Tax \mu_{c}^L');title('Average Consumption')


subplot(11,2,[14 16 18 20]);hold on;box on;
plot(lockdown_vec(start_lock_fig:end_lock_fig), mean(squeeze(Labor_mean(1,start_lock_fig:end_lock_fig,:))'),'b');
plot(lockdown_vec(start_lock_fig:end_lock_fig), mean(squeeze(Labor_mean(2,start_lock_fig:end_lock_fig,:))'),'-.','Color',[64 170 64]./255);
plot(lockdown_vec(start_lock_fig:end_lock_fig), mean(squeeze(Labor_mean(3,start_lock_fig:end_lock_fig,:))'),'r--');
title('Average Labor');xlabel('Consumption Tax \mu_{c}^L')
xlim([lockdown_vec(start_lock_fig) lockdown_vec(end_lock_fig)])

l1 = legend('Contact Tracing + Limited Tests','Contact Tracing + Unlimited Tests','Comprehensive + Limited Tests','Location','South','Orientation','horizontal');
l1.Position(2) = 0.025;l1.Position(1) = -0.03;

% scaling
fig.Units               = 'centimeters';
fig.Position(3)         = opts.width;
fig.Position(4)         = opts.height;
set(fig.Children,'FontName','Times','FontSize',9);

print([opts.saveFolder 'FigureH1_MR_JEEA'], '-dpng', '-r600')
print([opts.saveFolder 'FigureH1_MR_JEEA'], '-depsc2', '-r600')