% =========================================================================
% Code for "Pandemic Recessions and Contact Tracing"
% by Leonardo Melosi and Matthias Rottner
% Journal of the European Economic Association, forthcoming
% This function helps to solve the optimal policy for the economy with 
% contact tracing
% =========================================================================


function [U0]=getU_err(muc_guess,pf_n_s_guess,pf_n_i_guess,pf_n_r_guess,pf_n_c_guess,P,T)


%muc=zeros(T,1);
muc(1:numel(muc_guess))=muc_guess/P.scale_opt;

persistent guess_n_s guess_n_i guess_n_r guess_n_c n_s_vec n_i_vec n_r_vec n_c_vec
if isempty(guess_n_s)==1
    guess_n_s=pf_n_s_guess;
    guess_n_i=pf_n_i_guess;
    guess_n_r=pf_n_r_guess;
    guess_n_c=pf_n_c_guess;
    try

    [pf_U,guess_n_s,guess_n_i,guess_n_r,guess_n_c] = eqm_Exposure_trace_get_err(guess_n_s,guess_n_i,guess_n_r,guess_n_c,muc,P,T);
    catch
    end
else
    guess_n_s=n_s_vec;
    guess_n_i=n_i_vec;
    guess_n_r=n_r_vec;
    guess_n_c=n_c_vec;
end



try
  
  opts_fsolve_fmincon=optimoptions('fsolve','Display','off','TolFun',1e-9,'MaxFunctionEvaluations',10000);
   guess = [guess_n_s;guess_n_i(1);guess_n_r;guess_n_c(1)];  
   
   [n_vec,fval,exitflag]=fsolve(@eqm_Exposure_trace_alphac_get_err_1d,guess,opts_fsolve_fmincon,muc,P,T);
                                                              
    if exitflag~=1
        error('Fsolve could not solve the model');
    end

[err,pf_U,n_s_vec,n_i_vec,n_r_vec,n_c_vec] =eqm_Exposure_trace_alphac_get_err_1d(n_vec,muc,P,T);
  U0 = -100*pf_U(1); 

catch
    try
        %2
 
        [pf_U,guess_n_s,guess_n_i,guess_n_r,guess_n_c] = eqm_Exposure_trace_get_err(guess_n_s,guess_n_i,guess_n_r,guess_n_c,muc,P,T);
        opts_fsolve_fmincon=optimoptions('fsolve','Display','off','TolFun',1e-9);
        guess = [guess_n_s;guess_n_i(1);guess_n_r;guess_n_c(1)]; 
        [n_vec,fval,exitflag]=fsolve(@eqm_Exposure_trace_alphac_get_err_1d,guess,opts_fsolve_fmincon,muc,P,T);
                                                                
        if exitflag~=1
            error('Fsolve could not solve the model');
        end
        
        [err,pf_U,n_s_vec,n_i_vec,n_r_vec,n_c_vec] =eqm_Exposure_trace_alphac_get_err_1d(n_vec,muc,P,T);
        U0 = -100*pf_U(1); 
        
    catch
        
        try
            %3
            % Try with alternative guess
            guess_n_s=pf_n_s_guess;
            guess_n_i=pf_n_i_guess;
            guess_n_r=pf_n_r_guess;
            guess_n_c=pf_n_c_guess;
            
            [pf_U,guess_n_s,guess_n_i,guess_n_r,guess_n_c] = eqm_Exposure_trace_get_err(guess_n_s,guess_n_i,guess_n_r,guess_n_c,muc,P,T);
            opts_fsolve_fmincon=optimoptions('fsolve','Display','off','TolFun',1e-9);
            guess = [guess_n_s;guess_n_i(1);guess_n_r;guess_n_c(1)]; 
            [n_vec,fval,exitflag]=fsolve(@eqm_Exposure_trace_alphac_get_err_1d,guess,opts_fsolve_fmincon,muc,P,T);

            if exitflag~=1
                error('Fsolve could not solve the model');
            end

            [err,pf_U,n_s_vec,n_i_vec,n_r_vec,n_c_vec] =eqm_Exposure_trace_alphac_get_err_1d(n_vec,muc,P,T);
            U0 = -100*pf_U(1); 
           
        catch
            %4
            U0 = 100*1e10;
            guess_n_s = [];
            disp('Could not solve the model')
            disp(num2str(4))
        end

    end
end

end